@@ -1,4 +1,4 @@
 from b2_utils.tests.helpers import *  # noqa
 from b2_utils.tests.helpers import __all__ as _helpers_all
 
-__all__ = _helpers_all + []
+__all__ = _helpers_all  # noqa: PLE0605
